@@ -28,11 +28,11 @@ class BaseDBHandler(ABC):
         pass
 
     @abstractmethod
-    def delete_item(self, item_id: int, item_type: str):
+    def delete_item(self, item_id: int, item_type: type('Item')):
         pass
 
     @abstractmethod
-    def delete_items(self, item_ids: List[str], item_type: str):
+    def delete_items(self, item_ids: List[int], item_type: type('Item')):
         pass
 
     @abstractmethod
