@@ -36,11 +36,12 @@ class SqlDBHandler(BaseDBHandler):
     def update_item(self, item_data: 'Item'):
         raise NotImplementedError('Have not implemented update item')
 
-    def delete_item(self, item_id: int, item_type: str):
-        pass
+    def delete_item(self, item_id: int, item_type: type('Item')):
+        self.session.query(item_type).filter_by(id=item_id).delete()
 
-    def delete_items(self, item_ids: List[str], item_type: str):
-        pass
+    def delete_items(self, item_ids: List[int], item_type: type('Item')):
+        for item_id in item_ids:
+            self.delete_item(item_id, item_type)
 
     def rollback(self):
         self.session.rollback()
